glados.errors module — GLaDOS 0.0.1.dev14 documentation

# glados.errors module

exception `glados.errors.` `GladosBotNotFoundError`

  Bases: `glados.errors.GladosError`

  Error raised when GladosBot is not found

exception `glados.errors.` `GladosError`

  Bases: `Exception`

  Base class for Client errors

exception `glados.errors.` `GladosPathExistsError`

  Bases: `glados.errors.GladosError`

  Error raised when trying to add a path that already exists

exception `glados.errors.` `GladosRouteNotFoundError`

  Bases: `glados.errors.GladosError`

  Error raised when the requested path is not found